/*
 * Copyright (C) 2023-2025 Xeme Developers
 *
 * Xeme is the legal property of its developers, whose names are too
 * numerous to list here. Please refer to the AUTHORS file distributed
 * with this source distribution
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, see
 * <https://www.gnu.org/licenses/>.
 */

#ifndef XEME_ADDRESS_H
#define XEME_ADDRESS_H

#include <glib.h>
#include <glib-object.h>

#include <xeme/xemeversion.h>

G_BEGIN_DECLS

/**
 * xeme_address_parse:
 * @address: The address to parse.
 * @bare_jid: (nullable): An optional return address for the bare jid, that is
 *            the `local@domain` part of the jid including the `@`.
 * @local: (nullable): An optional return address for the localpart.
 * @domain: (nullable): An optional return address for the domainpart.
 * @resource: (nullable): An optional return address for the resourcepart.
 *
 * Splits @address according to the rules of
 * [RFC 6122](https://www.rfc-editor.org/rfc/rfc6122#section-2) and returns the
 * results into the optional @local, @domain, and @resource.
 *
 * Returns: %TRUE if @address was valid, otherwise %FALSE.
 *
 * Since: 0.1
 */
XEME_AVAILABLE_IN_0_1
gboolean xeme_address_parse(const char *address, char **bare_jid, char **local, char **domain, char **resource);

G_END_DECLS

#endif /* XEME_ADDRESS_H */
