/*
 * Copyright (C) 2023-2025 Xeme Developers
 *
 * Xeme is the legal property of its developers, whose names are too
 * numerous to list here. Please refer to the AUTHORS file distributed
 * with this source distribution
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, see
 * <https://www.gnu.org/licenses/>.
 */

#ifndef XEME_STRING_H
#define XEME_STRING_H

#include <glib.h>

#include "xemeversion.h"

G_BEGIN_DECLS

/**
 * xeme_str_is_empty:
 * @str: (nullable): The string to check.
 *
 * Determines if @str is empty or not.
 *
 * Returns: %TRUE if @str is empty, otherwise %FALSE.
 *
 * Since: 0.1
 */
XEME_AVAILABLE_STATIC_INLINE_IN_0_1
static inline gboolean
xeme_str_is_empty(const char *str) {
	return (str == NULL || str[0] == '\0');
}

/**
 * xeme_str_equal:
 * @str1: (nullable): The first string.
 * @str2: (nullable): The second string.
 *
 * Checks if @str1 is equal to @str2.
 *
 * Returns: %TRUE if the strings are equal or %FALSE.
 *
 * Since: 0.1
 */
XEME_AVAILABLE_STATIC_INLINE_IN_0_1
static inline gboolean
xeme_str_equal(const char *str1, const char *str2) {
	return (g_strcmp0(str1, str2) == 0);
}

G_END_DECLS


#endif /* XEME_STRING_H */
